@@ -93,6 +93,19 @@ class SFBulk2(object):
     failure_res = requests.get(jobs_failure_uri, headers=headers)
     return failure_res
 
+  def get_unprocessed_records(self, job_id=None):
+    if not job_id:
+      raise RuntimeError("Must provide job_id!")
+    jobs_failure_uri = '{}/services/data/{}/jobs/ingest/{}/unprocessedrecords/'.format(self.instance_url, self.api_version,job_id)
+    headers = {
+      'Authorization': 'Bearer ' + self.access_token,
+      'Content-Type': 'application/json;charset=UTF-8',
+      'Accept': 'application/json'
+    }
+    unprocessed_records = requests.get(jobs_failure_uri, headers=headers)
+    return unprocessed_records
+
+
   ### --------- QUERY -----------
   def create_query_job(self, query=None):
     operation = 'query'
@@ -173,7 +186,7 @@ class SFBulk2(object):
     }
 
     delete_res = requests.delete(delete_query_uri, headers=headers)
-    return detelete_res
+    return delete_res
     
 
   
